==> zzyj-outputvalcount-api-3.0.0-20220716.023318-59-sources.jar: com/ejianc/business/outputvalcount/vo/XmjdmxVO.java <==
package com.ejianc.business.outputvalcount.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目进度明细
 * 
 * @author generator
 * 
 */
public class XmjdmxVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long projectId; // 工程名称id
    private String projectName; // 工程名称
    private BigDecimal zje; // 总金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date statDate; // 产值统计日期
    private String description; // 形象进度描述
    private BigDecimal kgwccz; // 自开工累计完成产值
    private Integer year; // 年份
    private Integer month; // 月份
    private List<MonthlyStatisticsVO> statisticsList = new ArrayList();
    private List<MonthlyPlanVO> planList = new ArrayList();
    private List<XmyxglVO> xmyxglList = new ArrayList();
    private List<ProductionVO> productionList = new ArrayList<>();
    private BigDecimal bywccz; // 本月完成产值
    private Long proId; // 项目
    private BigDecimal taxMny; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date productionDate; // 产值时间


    public Long getProId() {
        return proId;
    }

    public void setProId(Long proId) {
        this.proId = proId;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public Date getProductionDate() {
        return productionDate;
    }

    public void setProductionDate(Date productionDate) {
        this.productionDate = productionDate;
    }

    public BigDecimal getBywccz() {
        return bywccz;
    }

    public void setBywccz(BigDecimal bywccz) {
        this.bywccz = bywccz;
    }

    public List<MonthlyPlanVO> getPlanList() {
        return planList;
    }

    public void setPlanList(List<MonthlyPlanVO> planList) {
        this.planList = planList;
    }

    public List<XmyxglVO> getXmyxglList() {
        return xmyxglList;
    }

    public void setXmyxglList(List<XmyxglVO> xmyxglList) {
        this.xmyxglList = xmyxglList;
    }

    public List<MonthlyStatisticsVO> getStatisticsList() {
        return statisticsList;
    }

    public void setStatisticsList(List<MonthlyStatisticsVO> statisticsList) {
        this.statisticsList = statisticsList;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public BigDecimal getZje() {
        return zje;
    }

    public void setZje(BigDecimal zje) {
        this.zje = zje;
    }
    public Date getStatDate() {
        return statDate;
    }

    public void setStatDate(Date statDate) {
        this.statDate = statDate;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public BigDecimal getKgwccz() {
        return kgwccz;
    }

    public void setKgwccz(BigDecimal kgwccz) {
        this.kgwccz = kgwccz;
    }
    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }

    public List<ProductionVO> getProductionList() {
        return productionList;
    }

    public void setProductionList(List<ProductionVO> productionList) {
        this.productionList = productionList;
    }
}

==> zzyj-outputvalcount-api-3.0.0-20220716.061407-60-sources.jar: com/ejianc/business/outputvalcount/vo/XmjdmxVO.java <==
package com.ejianc.business.outputvalcount.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目进度明细
 * 
 * @author generator
 * 
 */
public class XmjdmxVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long projectId; // 工程名称id
    private String projectName; // 工程名称
    private BigDecimal zje; // 总金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date statDate; // 产值统计日期
    private String description; // 形象进度描述
    private BigDecimal kgwccz; // 自开工累计完成产值
    private Integer year; // 年份
    private Integer month; // 月份
    private List<MonthlyStatisticsVO> statisticsList = new ArrayList();
    private List<MonthlyPlanVO> planList = new ArrayList();
    private List<XmyxglVO> xmyxglList = new ArrayList();
    private List<ProductionVO> productionList = new ArrayList<>();
    private BigDecimal bywccz; // 本月完成产值
    private Long proId; // 项目
    private BigDecimal taxMny; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date productionDate; // 产值时间
    private BigDecimal bnwccz; //


    public BigDecimal getBnwccz() {
        return bnwccz;
    }

    public void setBnwccz(BigDecimal bnwccz) {
        this.bnwccz = bnwccz;
    }

    public Long getProId() {
        return proId;
    }

    public void setProId(Long proId) {
        this.proId = proId;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public Date getProductionDate() {
        return productionDate;
    }

    public void setProductionDate(Date productionDate) {
        this.productionDate = productionDate;
    }

    public BigDecimal getBywccz() {
        return bywccz;
    }

    public void setBywccz(BigDecimal bywccz) {
        this.bywccz = bywccz;
    }

    public List<MonthlyPlanVO> getPlanList() {
        return planList;
    }

    public void setPlanList(List<MonthlyPlanVO> planList) {
        this.planList = planList;
    }

    public List<XmyxglVO> getXmyxglList() {
        return xmyxglList;
    }

    public void setXmyxglList(List<XmyxglVO> xmyxglList) {
        this.xmyxglList = xmyxglList;
    }

    public List<MonthlyStatisticsVO> getStatisticsList() {
        return statisticsList;
    }

    public void setStatisticsList(List<MonthlyStatisticsVO> statisticsList) {
        this.statisticsList = statisticsList;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public BigDecimal getZje() {
        return zje;
    }

    public void setZje(BigDecimal zje) {
        this.zje = zje;
    }
    public Date getStatDate() {
        return statDate;
    }

    public void setStatDate(Date statDate) {
        this.statDate = statDate;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public BigDecimal getKgwccz() {
        return kgwccz;
    }

    public void setKgwccz(BigDecimal kgwccz) {
        this.kgwccz = kgwccz;
    }
    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }

    public List<ProductionVO> getProductionList() {
        return productionList;
    }

    public void setProductionList(List<ProductionVO> productionList) {
        this.productionList = productionList;
    }
}
